==> deepin-fcitx5configtool-plugin_6.0.8.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi_FI">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-fcitx5configtool-plugin_6.0.12.tar.xz: BUILD/src/dcc-fcitx5configtool/translations/fcitx5configtool_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>Lisäosat</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="14"/>
        <source>Advanced Settings</source>
        <translation>Lisäasetukset</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="28"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;Lisäasetukset&quot; on voimassa vain sitä syöttömenetelmää varten, joka käyttää järjestelmäasetuksia, jos syöttömenetelmällä on omat asetukset, niin omat asetukset voimassa.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>Global Config</source>
        <translation>Maailmanlaajuiset asetukset</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="52"/>
        <source>Add-ons</source>
        <translation>Lisäosat</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="126"/>
        <source>Please enter a new shortcut</source>
        <translation>Syötä uusi pikakäsky</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="54"/>
        <source>Move Up</source>
        <translation>Siirrä ylös</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="61"/>
        <source>Move Down</source>
        <translation>Siirrä alas</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="69"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="76"/>
        <source>Remove</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="29"/>
        <source>Add input method</source>
        <translation>Lisää syöttömenetelmä</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="37"/>
        <source>Search</source>
        <translation>Etsi</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="102"/>
        <source>Find more in App Store</source>
        <translation>Etsi lisää App Storesta</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="121"/>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="128"/>
        <source>Add</source>
        <translation>Lisää</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>Syöttömenetelmähallinta</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="29"/>
        <source>Add input method</source>
        <translation>Lisää syöttömenetelmä</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="34"/>
        <source>Shortcuts</source>
        <translation>Pikakäkset</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="45"/>
        <source>Restore Defaults</source>
        <translation>Palauta oletusarvot</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="97"/>
        <source>Scroll between input methods</source>
        <translation>Vaihda syöttömenetelmiä hiirellä</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="127"/>
        <source>Turn on or off input methods</source>
        <translation>Päälle- tai pois-kytkentä syöttömenetelmille</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="131"/>
        <source>Please enter a new shortcut</source>
        <translation>Syötä uusi pikakäsky</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="156"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>Se käyttää päälle- tai pois-kytkentää nykyisesti käytettävälle syöttömenetelmälle. Jos ei käytetä syöttömenetelmää tai ensimmäinen syöttömenetelmä ei ole näppäimistö, se vaihtaa ensimmäistä syöttömenetelmää ja nykyistä käytettävää näppäimistöä/syöttömenetelmää.</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>Syöttömenetelmät</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>Syöttömenetelmähallinta, syöttömenetelmäpikakäkset, lisäasetukset</translation>
    </message>
</context>
</TS>
